summary refs log tree commit diff
diff options
context:
space:
mode:
authorclaudiiii <claudi+github@grimm.link>2020-07-15 22:39:34 +0200
committerclaudiiii <claudi+github@grimm.link>2020-07-15 22:39:34 +0200
commita705201e1d771444667c59c8cc2357c4afb88e21 (patch)
tree4508e954fb80116f06fc12cfe1b7000af08c4fb2
parentb314827afdf6385df5e107d687bdcc9e2f24cb64 (diff)
downloadnixpkgs-a705201e1d771444667c59c8cc2357c4afb88e21.tar
nixpkgs-a705201e1d771444667c59c8cc2357c4afb88e21.tar.gz
nixpkgs-a705201e1d771444667c59c8cc2357c4afb88e21.tar.bz2
nixpkgs-a705201e1d771444667c59c8cc2357c4afb88e21.tar.lz
nixpkgs-a705201e1d771444667c59c8cc2357c4afb88e21.tar.xz
nixpkgs-a705201e1d771444667c59c8cc2357c4afb88e21.tar.zst
nixpkgs-a705201e1d771444667c59c8cc2357c4afb88e21.zip
element-desktop, element-web: init at 1.7.0
-rw-r--r--pkgs/applications/networking/instant-messengers/element/element-desktop-package.json (renamed from pkgs/applications/networking/instant-messengers/riot/riot-desktop-package.json)29
-rw-r--r--pkgs/applications/networking/instant-messengers/element/element-desktop-yarndeps.nix (renamed from pkgs/applications/networking/instant-messengers/riot/riot-desktop-yarndeps.nix)424
-rw-r--r--pkgs/applications/networking/instant-messengers/element/element-desktop.nix (renamed from pkgs/applications/networking/instant-messengers/riot/riot-desktop.nix)55
-rw-r--r--pkgs/applications/networking/instant-messengers/element/element-web.nix (renamed from pkgs/applications/networking/instant-messengers/riot/riot-web.nix)12
-rwxr-xr-xpkgs/applications/networking/instant-messengers/element/update-element-desktop.sh17
-rwxr-xr-xpkgs/applications/networking/instant-messengers/riot/update-riot-desktop.sh17
-rw-r--r--pkgs/top-level/aliases.nix2
-rw-r--r--pkgs/top-level/all-packages.nix12
8 files changed, 360 insertions, 208 deletions
diff --git a/pkgs/applications/networking/instant-messengers/riot/riot-desktop-package.json b/pkgs/applications/networking/instant-messengers/element/element-desktop-package.json
index f3e7732686f..43a03eab8a9 100644
--- a/pkgs/applications/networking/instant-messengers/riot/riot-desktop-package.json
+++ b/pkgs/applications/networking/instant-messengers/element/element-desktop-package.json
@@ -1,10 +1,10 @@
 {
-  "name": "riot-desktop",
-  "productName": "Riot",
+  "name": "element-desktop",
+  "productName": "Element (Riot)",
   "main": "src/electron-main.js",
-  "version": "1.6.7",
+  "version": "1.7.0",
   "description": "A feature-rich client for Matrix.org",
-  "author": "New Vector Ltd.",
+  "author": "Element",
   "repository": {
     "type": "git",
     "url": "https://github.com/vector-im/riot-desktop"
@@ -38,8 +38,8 @@
   },
   "devDependencies": {
     "asar": "^2.0.1",
-    "electron-builder": "^22.3.2",
-    "electron-builder-squirrel-windows": "^22.3.2",
+    "electron-builder": "^22.7.0",
+    "electron-builder-squirrel-windows": "^22.7.0",
     "electron-devtools-installer": "^2.2.4",
     "electron-notarize": "^0.2.0",
     "eslint": "^5.8.0",
@@ -48,22 +48,22 @@
     "find-npm-prefix": "^1.0.2",
     "fs-extra": "^8.1.0",
     "glob": "^7.1.6",
-    "matrix-js-sdk": "7.0.0",
+    "matrix-js-sdk": "7.1.0",
     "mkdirp": "^1.0.3",
     "needle": "^2.5.0",
     "node-pre-gyp": "^0.15.0",
-    "npm": "^6.13.7",
+    "npm": "^6.14.6",
     "rimraf": "^3.0.2",
     "semver": "^7.1.3",
     "tar": "^6.0.1"
   },
   "hakDependencies": {
-    "matrix-seshat": "^1.3.3",
+    "matrix-seshat": "^2.1.0",
     "keytar": "^5.6.0"
   },
   "build": {
     "appId": "im.riot.app",
-    "electronVersion": "8.0.3",
+    "electronVersion": "9.0.5",
     "files": [
       "package.json",
       {
@@ -82,9 +82,9 @@
     "linux": {
       "target": "deb",
       "category": "Network;InstantMessaging;Chat",
-      "maintainer": "support@riot.im",
+      "maintainer": "support@element.io",
       "desktop": {
-        "StartupWMClass": "riot"
+        "StartupWMClass": "element"
       }
     },
     "mac": {
@@ -100,12 +100,13 @@
     "directories": {
       "output": "dist"
     },
+    "afterPack": "scripts/electron_afterPack",
     "afterSign": "scripts/electron_afterSign",
     "protocols": [
       {
-        "name": "riot",
+        "name": "element",
         "schemes": [
-          "riot"
+          "element"
         ]
       }
     ]
diff --git a/pkgs/applications/networking/instant-messengers/riot/riot-desktop-yarndeps.nix b/pkgs/applications/networking/instant-messengers/element/element-desktop-yarndeps.nix
index 2fa0303ae05..a5c3856d29f 100644
--- a/pkgs/applications/networking/instant-messengers/riot/riot-desktop-yarndeps.nix
+++ b/pkgs/applications/networking/instant-messengers/element/element-desktop-yarndeps.nix
@@ -2,14 +2,6 @@
   offline_cache = linkFarm "offline" packages;
   packages = [
     {
-      name = "7zip_bin___7zip_bin_4.0.2.tgz";
-      path = fetchurl {
-        name = "7zip_bin___7zip_bin_4.0.2.tgz";
-        url  = "https://registry.yarnpkg.com/7zip-bin/-/7zip-bin-4.0.2.tgz";
-        sha1 = "6abbdc22f33cab742053777a26db2e25ca527179";
-      };
-    }
-    {
       name = "7zip_bin___7zip_bin_5.0.3.tgz";
       path = fetchurl {
         name = "7zip_bin___7zip_bin_5.0.3.tgz";
@@ -50,11 +42,11 @@
       };
     }
     {
-      name = "_develar_schema_utils___schema_utils_2.1.0.tgz";
+      name = "_develar_schema_utils___schema_utils_2.6.5.tgz";
       path = fetchurl {
-        name = "_develar_schema_utils___schema_utils_2.1.0.tgz";
-        url  = "https://registry.yarnpkg.com/@develar/schema-utils/-/schema-utils-2.1.0.tgz";
-        sha1 = "eceb1695bfbed6f6bb84666d5d3abe5e1fd54e17";
+        name = "_develar_schema_utils___schema_utils_2.6.5.tgz";
+        url  = "https://registry.yarnpkg.com/@develar/schema-utils/-/schema-utils-2.6.5.tgz";
+        sha1 = "3ece22c5838402419a6e0425f85742b961d9b6c6";
       };
     }
     {
@@ -98,11 +90,11 @@
       };
     }
     {
-      name = "_types_fs_extra___fs_extra_8.0.1.tgz";
+      name = "_types_fs_extra___fs_extra_9.0.1.tgz";
       path = fetchurl {
-        name = "_types_fs_extra___fs_extra_8.0.1.tgz";
-        url  = "https://registry.yarnpkg.com/@types/fs-extra/-/fs-extra-8.0.1.tgz";
-        sha1 = "a2378d6e7e8afea1564e44aafa2e207dadf77686";
+        name = "_types_fs_extra___fs_extra_9.0.1.tgz";
+        url  = "https://registry.yarnpkg.com/@types/fs-extra/-/fs-extra-9.0.1.tgz";
+        sha1 = "91c8fc4c51f6d5dbe44c2ca9ab09310bd00c7918";
       };
     }
     {
@@ -122,6 +114,22 @@
       };
     }
     {
+      name = "_types_yargs_parser___yargs_parser_15.0.0.tgz";
+      path = fetchurl {
+        name = "_types_yargs_parser___yargs_parser_15.0.0.tgz";
+        url  = "https://registry.yarnpkg.com/@types/yargs-parser/-/yargs-parser-15.0.0.tgz";
+        sha1 = "cb3f9f741869e20cce330ffbeb9271590483882d";
+      };
+    }
+    {
+      name = "_types_yargs___yargs_15.0.5.tgz";
+      path = fetchurl {
+        name = "_types_yargs___yargs_15.0.5.tgz";
+        url  = "https://registry.yarnpkg.com/@types/yargs/-/yargs-15.0.5.tgz";
+        sha1 = "947e9a6561483bdee9adffc983e91a6902af8b79";
+      };
+    }
+    {
       name = "JSONStream___JSONStream_1.3.5.tgz";
       path = fetchurl {
         name = "JSONStream___JSONStream_1.3.5.tgz";
@@ -194,6 +202,14 @@
       };
     }
     {
+      name = "ajv___ajv_6.12.2.tgz";
+      path = fetchurl {
+        name = "ajv___ajv_6.12.2.tgz";
+        url  = "https://registry.yarnpkg.com/ajv/-/ajv-6.12.2.tgz";
+        sha1 = "c629c5eced17baf314437918d2da88c99d5958cd";
+      };
+    }
+    {
       name = "another_json___another_json_0.2.0.tgz";
       path = fetchurl {
         name = "another_json___another_json_0.2.0.tgz";
@@ -290,27 +306,19 @@
       };
     }
     {
-      name = "app_builder_bin___app_builder_bin_3.5.2.tgz";
-      path = fetchurl {
-        name = "app_builder_bin___app_builder_bin_3.5.2.tgz";
-        url  = "https://registry.yarnpkg.com/app-builder-bin/-/app-builder-bin-3.5.2.tgz";
-        sha1 = "fba56e6e9ef76fcd37816738c5f9a0b3992d7183";
-      };
-    }
-    {
-      name = "app_builder_lib___app_builder_lib_22.3.2.tgz";
+      name = "app_builder_bin___app_builder_bin_3.5.9.tgz";
       path = fetchurl {
-        name = "app_builder_lib___app_builder_lib_22.3.2.tgz";
-        url  = "https://registry.yarnpkg.com/app-builder-lib/-/app-builder-lib-22.3.2.tgz";
-        sha1 = "d43e0bdff91d484c0bd07d7248043dbb2665b8ac";
+        name = "app_builder_bin___app_builder_bin_3.5.9.tgz";
+        url  = "https://registry.yarnpkg.com/app-builder-bin/-/app-builder-bin-3.5.9.tgz";
+        sha1 = "a3ac0c25286bac68357321cb2eaf7128b0bc0a4f";
       };
     }
     {
-      name = "app_builder_lib___app_builder_lib_22.3.3.tgz";
+      name = "app_builder_lib___app_builder_lib_22.7.0.tgz";
       path = fetchurl {
-        name = "app_builder_lib___app_builder_lib_22.3.3.tgz";
-        url  = "https://registry.yarnpkg.com/app-builder-lib/-/app-builder-lib-22.3.3.tgz";
-        sha1 = "9a95a3c14f69fb6131834dd840fba561191c9998";
+        name = "app_builder_lib___app_builder_lib_22.7.0.tgz";
+        url  = "https://registry.yarnpkg.com/app-builder-lib/-/app-builder-lib-22.7.0.tgz";
+        sha1 = "ccd3e7ece2d46bc209423a77aa142f74aaf65db0";
       };
     }
     {
@@ -346,11 +354,11 @@
       };
     }
     {
-      name = "archiver___archiver_3.1.1.tgz";
+      name = "archiver___archiver_4.0.1.tgz";
       path = fetchurl {
-        name = "archiver___archiver_3.1.1.tgz";
-        url  = "https://registry.yarnpkg.com/archiver/-/archiver-3.1.1.tgz";
-        sha1 = "9db7819d4daf60aec10fe86b16cb9258ced66ea0";
+        name = "archiver___archiver_4.0.1.tgz";
+        url  = "https://registry.yarnpkg.com/archiver/-/archiver-4.0.1.tgz";
+        sha1 = "3f722b121777e361ca9fad374ecda38e77e63c7f";
       };
     }
     {
@@ -426,6 +434,14 @@
       };
     }
     {
+      name = "async___async_0.9.2.tgz";
+      path = fetchurl {
+        name = "async___async_0.9.2.tgz";
+        url  = "https://registry.yarnpkg.com/async/-/async-0.9.2.tgz";
+        sha1 = "aea74d5e61c1f899613bf64bda66d4c78f2fd17d";
+      };
+    }
+    {
       name = "async___async_2.6.3.tgz";
       path = fetchurl {
         name = "async___async_2.6.3.tgz";
@@ -442,6 +458,14 @@
       };
     }
     {
+      name = "at_least_node___at_least_node_1.0.0.tgz";
+      path = fetchurl {
+        name = "at_least_node___at_least_node_1.0.0.tgz";
+        url  = "https://registry.yarnpkg.com/at-least-node/-/at-least-node-1.0.0.tgz";
+        sha1 = "602cd4b46e844ad4effc92a8011a3c46e0238dc2";
+      };
+    }
+    {
       name = "auto_launch___auto_launch_5.0.5.tgz";
       path = fetchurl {
         name = "auto_launch___auto_launch_5.0.5.tgz";
@@ -514,11 +538,11 @@
       };
     }
     {
-      name = "bl___bl_3.0.0.tgz";
+      name = "bl___bl_4.0.2.tgz";
       path = fetchurl {
-        name = "bl___bl_3.0.0.tgz";
-        url  = "https://registry.yarnpkg.com/bl/-/bl-3.0.0.tgz";
-        sha1 = "3611ec00579fd18561754360b21e9f784500ff88";
+        name = "bl___bl_4.0.2.tgz";
+        url  = "https://registry.yarnpkg.com/bl/-/bl-4.0.2.tgz";
+        sha1 = "52b71e9088515d0606d9dd9cc7aa48dc1f98e73a";
       };
     }
     {
@@ -618,27 +642,27 @@
       };
     }
     {
-      name = "builder_util_runtime___builder_util_runtime_8.6.0.tgz";
+      name = "buffer___buffer_5.6.0.tgz";
       path = fetchurl {
-        name = "builder_util_runtime___builder_util_runtime_8.6.0.tgz";
-        url  = "https://registry.yarnpkg.com/builder-util-runtime/-/builder-util-runtime-8.6.0.tgz";
-        sha1 = "b7007c30126da9a90e99932128d2922c8c178649";
+        name = "buffer___buffer_5.6.0.tgz";
+        url  = "https://registry.yarnpkg.com/buffer/-/buffer-5.6.0.tgz";
+        sha1 = "a31749dc7d81d84db08abf937b6b8c4033f62786";
       };
     }
     {
-      name = "builder_util___builder_util_22.3.2.tgz";
+      name = "builder_util_runtime___builder_util_runtime_8.7.1.tgz";
       path = fetchurl {
-        name = "builder_util___builder_util_22.3.2.tgz";
-        url  = "https://registry.yarnpkg.com/builder-util/-/builder-util-22.3.2.tgz";
-        sha1 = "23c61aaf0f0006f994087b33a26e47cdaec7aa8d";
+        name = "builder_util_runtime___builder_util_runtime_8.7.1.tgz";
+        url  = "https://registry.yarnpkg.com/builder-util-runtime/-/builder-util-runtime-8.7.1.tgz";
+        sha1 = "23c808cddd650d4376a7a1518ec1e80e85c10f00";
       };
     }
     {
-      name = "builder_util___builder_util_22.3.3.tgz";
+      name = "builder_util___builder_util_22.7.0.tgz";
       path = fetchurl {
-        name = "builder_util___builder_util_22.3.3.tgz";
-        url  = "https://registry.yarnpkg.com/builder-util/-/builder-util-22.3.3.tgz";
-        sha1 = "62f0527ceaa1a2e4a60596a9b38ad1ffe3e20ae6";
+        name = "builder_util___builder_util_22.7.0.tgz";
+        url  = "https://registry.yarnpkg.com/builder-util/-/builder-util-22.7.0.tgz";
+        sha1 = "0776a66e6d6e408a78bed7f17a7ad22516d9e7f0";
       };
     }
     {
@@ -746,6 +770,14 @@
       };
     }
     {
+      name = "chalk___chalk_4.1.0.tgz";
+      path = fetchurl {
+        name = "chalk___chalk_4.1.0.tgz";
+        url  = "https://registry.yarnpkg.com/chalk/-/chalk-4.1.0.tgz";
+        sha1 = "4e14870a618d9e2edd97dd8345fd9d9dc315646a";
+      };
+    }
+    {
       name = "chardet___chardet_0.7.0.tgz";
       path = fetchurl {
         name = "chardet___chardet_0.7.0.tgz";
@@ -970,11 +1002,11 @@
       };
     }
     {
-      name = "compress_commons___compress_commons_2.1.1.tgz";
+      name = "compress_commons___compress_commons_3.0.0.tgz";
       path = fetchurl {
-        name = "compress_commons___compress_commons_2.1.1.tgz";
-        url  = "https://registry.yarnpkg.com/compress-commons/-/compress-commons-2.1.1.tgz";
-        sha1 = "9410d9a534cf8435e3fbbb7c6ce48de2dc2f0610";
+        name = "compress_commons___compress_commons_3.0.0.tgz";
+        url  = "https://registry.yarnpkg.com/compress-commons/-/compress-commons-3.0.0.tgz";
+        sha1 = "833944d84596e537224dd91cf92f5246823d4f1d";
       };
     }
     {
@@ -1170,6 +1202,14 @@
       };
     }
     {
+      name = "debug___debug_4.2.0.tgz";
+      path = fetchurl {
+        name = "debug___debug_4.2.0.tgz";
+        url  = "https://registry.yarnpkg.com/debug/-/debug-4.2.0.tgz";
+        sha1 = "7f150f93920e94c58f5574c2fd01a3110effe7f1";
+      };
+    }
+    {
       name = "debuglog___debuglog_1.0.1.tgz";
       path = fetchurl {
         name = "debuglog___debuglog_1.0.1.tgz";
@@ -1298,11 +1338,11 @@
       };
     }
     {
-      name = "dmg_builder___dmg_builder_22.3.2.tgz";
+      name = "dmg_builder___dmg_builder_22.7.0.tgz";
       path = fetchurl {
-        name = "dmg_builder___dmg_builder_22.3.2.tgz";
-        url  = "https://registry.yarnpkg.com/dmg-builder/-/dmg-builder-22.3.2.tgz";
-        sha1 = "4c052f75d601e3358da1ff9d7d57738e1c01b157";
+        name = "dmg_builder___dmg_builder_22.7.0.tgz";
+        url  = "https://registry.yarnpkg.com/dmg-builder/-/dmg-builder-22.7.0.tgz";
+        sha1 = "ead7e7c046cbdc52d29d302a4455f6668cdf7d45";
       };
     }
     {
@@ -1394,27 +1434,27 @@
       };
     }
     {
-      name = "ejs___ejs_3.0.1.tgz";
+      name = "ejs___ejs_3.1.3.tgz";
       path = fetchurl {
-        name = "ejs___ejs_3.0.1.tgz";
-        url  = "https://registry.yarnpkg.com/ejs/-/ejs-3.0.1.tgz";
-        sha1 = "30c8f6ee9948502cc32e85c37a3f8b39b5a614a5";
+        name = "ejs___ejs_3.1.3.tgz";
+        url  = "https://registry.yarnpkg.com/ejs/-/ejs-3.1.3.tgz";
+        sha1 = "514d967a8894084d18d3d47bd169a1c0560f093d";
       };
     }
     {
-      name = "electron_builder_squirrel_windows___electron_builder_squirrel_windows_22.3.3.tgz";
+      name = "electron_builder_squirrel_windows___electron_builder_squirrel_windows_22.7.0.tgz";
       path = fetchurl {
-        name = "electron_builder_squirrel_windows___electron_builder_squirrel_windows_22.3.3.tgz";
-        url  = "https://registry.yarnpkg.com/electron-builder-squirrel-windows/-/electron-builder-squirrel-windows-22.3.3.tgz";
-        sha1 = "0a417af35c83b067096bd3217b6b7bd75c6c48a9";
+        name = "electron_builder_squirrel_windows___electron_builder_squirrel_windows_22.7.0.tgz";
+        url  = "https://registry.yarnpkg.com/electron-builder-squirrel-windows/-/electron-builder-squirrel-windows-22.7.0.tgz";
+        sha1 = "8d6f09d541c039f52202935c66d592c38575ceff";
       };
     }
     {
-      name = "electron_builder___electron_builder_22.3.2.tgz";
+      name = "electron_builder___electron_builder_22.7.0.tgz";
       path = fetchurl {
-        name = "electron_builder___electron_builder_22.3.2.tgz";
-        url  = "https://registry.yarnpkg.com/electron-builder/-/electron-builder-22.3.2.tgz";
-        sha1 = "902d150fc0670cb90213262e5e0aa3c4f299ffa4";
+        name = "electron_builder___electron_builder_22.7.0.tgz";
+        url  = "https://registry.yarnpkg.com/electron-builder/-/electron-builder-22.7.0.tgz";
+        sha1 = "a42d08a1654ffc2f7d9e2860829d3cc55d4a0c81";
       };
     }
     {
@@ -1434,19 +1474,11 @@
       };
     }
     {
-      name = "electron_publish___electron_publish_22.3.2.tgz";
+      name = "electron_publish___electron_publish_22.7.0.tgz";
       path = fetchurl {
-        name = "electron_publish___electron_publish_22.3.2.tgz";
-        url  = "https://registry.yarnpkg.com/electron-publish/-/electron-publish-22.3.2.tgz";
-        sha1 = "d2e60caf7a9643fe57e501c20acaf32c737b1c50";
-      };
-    }
-    {
-      name = "electron_publish___electron_publish_22.3.3.tgz";
-      path = fetchurl {
-        name = "electron_publish___electron_publish_22.3.3.tgz";
-        url  = "https://registry.yarnpkg.com/electron-publish/-/electron-publish-22.3.3.tgz";
-        sha1 = "7d1e757a20ce0558fdc42900b6e3d773fdae9d9e";
+        name = "electron_publish___electron_publish_22.7.0.tgz";
+        url  = "https://registry.yarnpkg.com/electron-publish/-/electron-publish-22.7.0.tgz";
+        sha1 = "d92ba7c4007c9ac1dd070593e48028184fb2dc19";
       };
     }
     {
@@ -1754,6 +1786,14 @@
       };
     }
     {
+      name = "fast_deep_equal___fast_deep_equal_3.1.3.tgz";
+      path = fetchurl {
+        name = "fast_deep_equal___fast_deep_equal_3.1.3.tgz";
+        url  = "https://registry.yarnpkg.com/fast-deep-equal/-/fast-deep-equal-3.1.3.tgz";
+        sha1 = "3a7d56b559d6cbc3eb512325244e619a65c6c525";
+      };
+    }
+    {
       name = "fast_json_stable_stringify___fast_json_stable_stringify_2.0.0.tgz";
       path = fetchurl {
         name = "fast_json_stable_stringify___fast_json_stable_stringify_2.0.0.tgz";
@@ -1802,6 +1842,14 @@
       };
     }
     {
+      name = "filelist___filelist_1.0.1.tgz";
+      path = fetchurl {
+        name = "filelist___filelist_1.0.1.tgz";
+        url  = "https://registry.yarnpkg.com/filelist/-/filelist-1.0.1.tgz";
+        sha1 = "f10d1a3ae86c1694808e8f20906f43d4c9132dbb";
+      };
+    }
+    {
       name = "find_npm_prefix___find_npm_prefix_1.0.2.tgz";
       path = fetchurl {
         name = "find_npm_prefix___find_npm_prefix_1.0.2.tgz";
@@ -1906,6 +1954,14 @@
       };
     }
     {
+      name = "fs_extra___fs_extra_9.0.1.tgz";
+      path = fetchurl {
+        name = "fs_extra___fs_extra_9.0.1.tgz";
+        url  = "https://registry.yarnpkg.com/fs-extra/-/fs-extra-9.0.1.tgz";
+        sha1 = "910da0062437ba4c39fedd863f1675ccfefcb9fc";
+      };
+    }
+    {
       name = "fs_minipass___fs_minipass_1.2.7.tgz";
       path = fetchurl {
         name = "fs_minipass___fs_minipass_1.2.7.tgz";
@@ -2098,6 +2154,14 @@
       };
     }
     {
+      name = "graceful_fs___graceful_fs_4.2.4.tgz";
+      path = fetchurl {
+        name = "graceful_fs___graceful_fs_4.2.4.tgz";
+        url  = "https://registry.yarnpkg.com/graceful-fs/-/graceful-fs-4.2.4.tgz";
+        sha1 = "2256bde14d3632958c465ebc96dc467ca07a29fb";
+      };
+    }
+    {
       name = "har_schema___har_schema_2.0.0.tgz";
       path = fetchurl {
         name = "har_schema___har_schema_2.0.0.tgz";
@@ -2170,11 +2234,19 @@
       };
     }
     {
-      name = "hosted_git_info___hosted_git_info_3.0.2.tgz";
+      name = "hosted_git_info___hosted_git_info_2.8.8.tgz";
       path = fetchurl {
-        name = "hosted_git_info___hosted_git_info_3.0.2.tgz";
-        url  = "https://registry.yarnpkg.com/hosted-git-info/-/hosted-git-info-3.0.2.tgz";
-        sha1 = "8b7e3bd114b59b51786f8bade0f39ddc80275a97";
+        name = "hosted_git_info___hosted_git_info_2.8.8.tgz";
+        url  = "https://registry.yarnpkg.com/hosted-git-info/-/hosted-git-info-2.8.8.tgz";
+        sha1 = "7539bd4bc1e0e0a895815a2e0262420b12858488";
+      };
+    }
+    {
+      name = "hosted_git_info___hosted_git_info_3.0.4.tgz";
+      path = fetchurl {
+        name = "hosted_git_info___hosted_git_info_3.0.4.tgz";
+        url  = "https://registry.yarnpkg.com/hosted-git-info/-/hosted-git-info-3.0.4.tgz";
+        sha1 = "be4973eb1fd2737b11c9c7c19380739bb249f60d";
       };
     }
     {
@@ -2626,11 +2698,11 @@
       };
     }
     {
-      name = "isbinaryfile___isbinaryfile_4.0.4.tgz";
+      name = "isbinaryfile___isbinaryfile_4.0.6.tgz";
       path = fetchurl {
-        name = "isbinaryfile___isbinaryfile_4.0.4.tgz";
-        url  = "https://registry.yarnpkg.com/isbinaryfile/-/isbinaryfile-4.0.4.tgz";
-        sha1 = "6803f81a8944201c642b6e17da041e24deb78712";
+        name = "isbinaryfile___isbinaryfile_4.0.6.tgz";
+        url  = "https://registry.yarnpkg.com/isbinaryfile/-/isbinaryfile-4.0.6.tgz";
+        sha1 = "edcb62b224e2b4710830b67498c8e4e5a4d2610b";
       };
     }
     {
@@ -2650,6 +2722,14 @@
       };
     }
     {
+      name = "jake___jake_10.8.2.tgz";
+      path = fetchurl {
+        name = "jake___jake_10.8.2.tgz";
+        url  = "https://registry.yarnpkg.com/jake/-/jake-10.8.2.tgz";
+        sha1 = "ebc9de8558160a66d82d0eadc6a2e58fbc500a7b";
+      };
+    }
+    {
       name = "jimp___jimp_0.2.28.tgz";
       path = fetchurl {
         name = "jimp___jimp_0.2.28.tgz";
@@ -2682,6 +2762,14 @@
       };
     }
     {
+      name = "js_yaml___js_yaml_3.14.0.tgz";
+      path = fetchurl {
+        name = "js_yaml___js_yaml_3.14.0.tgz";
+        url  = "https://registry.yarnpkg.com/js-yaml/-/js-yaml-3.14.0.tgz";
+        sha1 = "a7a34170f26a21bb162424d8adacb4113a69e482";
+      };
+    }
+    {
       name = "jsbn___jsbn_0.1.1.tgz";
       path = fetchurl {
         name = "jsbn___jsbn_0.1.1.tgz";
@@ -2738,11 +2826,11 @@
       };
     }
     {
-      name = "json5___json5_2.1.1.tgz";
+      name = "json5___json5_2.1.3.tgz";
       path = fetchurl {
-        name = "json5___json5_2.1.1.tgz";
-        url  = "https://registry.yarnpkg.com/json5/-/json5-2.1.1.tgz";
-        sha1 = "81b6cb04e9ba496f1c7005d07b4368a2638f90b6";
+        name = "json5___json5_2.1.3.tgz";
+        url  = "https://registry.yarnpkg.com/json5/-/json5-2.1.3.tgz";
+        sha1 = "c9b0f7fa9233bfe5807fe66fcf3a5617ed597d43";
       };
     }
     {
@@ -2762,6 +2850,14 @@
       };
     }
     {
+      name = "jsonfile___jsonfile_6.0.1.tgz";
+      path = fetchurl {
+        name = "jsonfile___jsonfile_6.0.1.tgz";
+        url  = "https://registry.yarnpkg.com/jsonfile/-/jsonfile-6.0.1.tgz";
+        sha1 = "98966cba214378c8c84b82e085907b40bf614179";
+      };
+    }
+    {
       name = "jsonparse___jsonparse_1.3.1.tgz";
       path = fetchurl {
         name = "jsonparse___jsonparse_1.3.1.tgz";
@@ -3154,11 +3250,11 @@
       };
     }
     {
-      name = "matrix_js_sdk___matrix_js_sdk_7.0.0.tgz";
+      name = "matrix_js_sdk___matrix_js_sdk_7.1.0.tgz";
       path = fetchurl {
-        name = "matrix_js_sdk___matrix_js_sdk_7.0.0.tgz";
-        url  = "https://registry.yarnpkg.com/matrix-js-sdk/-/matrix-js-sdk-7.0.0.tgz";
-        sha1 = "da2b24e57574379c3d8f7065eb68ea6c479d9806";
+        name = "matrix_js_sdk___matrix_js_sdk_7.1.0.tgz";
+        url  = "https://registry.yarnpkg.com/matrix-js-sdk/-/matrix-js-sdk-7.1.0.tgz";
+        sha1 = "b3e3304e890df45c827706831748935168ee839f";
       };
     }
     {
@@ -3210,11 +3306,11 @@
       };
     }
     {
-      name = "mime___mime_2.4.4.tgz";
+      name = "mime___mime_2.4.6.tgz";
       path = fetchurl {
-        name = "mime___mime_2.4.4.tgz";
-        url  = "https://registry.yarnpkg.com/mime/-/mime-2.4.4.tgz";
-        sha1 = "bd7b91135fc6b01cde3e9bae33d659b63d8857e5";
+        name = "mime___mime_2.4.6.tgz";
+        url  = "https://registry.yarnpkg.com/mime/-/mime-2.4.6.tgz";
+        sha1 = "e5b407c90db442f2beb5b162373d07b69affa4d1";
       };
     }
     {
@@ -3426,6 +3522,14 @@
       };
     }
     {
+      name = "node_gyp___node_gyp_5.1.1.tgz";
+      path = fetchurl {
+        name = "node_gyp___node_gyp_5.1.1.tgz";
+        url  = "https://registry.yarnpkg.com/node-gyp/-/node-gyp-5.1.1.tgz";
+        sha1 = "eb915f7b631c937d282e33aed44cb7a025f62a3e";
+      };
+    }
+    {
       name = "node_pre_gyp___node_pre_gyp_0.15.0.tgz";
       path = fetchurl {
         name = "node_pre_gyp___node_pre_gyp_0.15.0.tgz";
@@ -3442,6 +3546,14 @@
       };
     }
     {
+      name = "nopt___nopt_4.0.3.tgz";
+      path = fetchurl {
+        name = "nopt___nopt_4.0.3.tgz";
+        url  = "https://registry.yarnpkg.com/nopt/-/nopt-4.0.3.tgz";
+        sha1 = "a375cad9d02fd921278d954c2254d5aa57e15e48";
+      };
+    }
+    {
       name = "normalize_package_data___normalize_package_data_2.5.0.tgz";
       path = fetchurl {
         name = "normalize_package_data___normalize_package_data_2.5.0.tgz";
@@ -3554,6 +3666,14 @@
       };
     }
     {
+      name = "npm_profile___npm_profile_4.0.4.tgz";
+      path = fetchurl {
+        name = "npm_profile___npm_profile_4.0.4.tgz";
+        url  = "https://registry.yarnpkg.com/npm-profile/-/npm-profile-4.0.4.tgz";
+        sha1 = "28ee94390e936df6d084263ee2061336a6a1581b";
+      };
+    }
+    {
       name = "npm_registry_fetch___npm_registry_fetch_4.0.2.tgz";
       path = fetchurl {
         name = "npm_registry_fetch___npm_registry_fetch_4.0.2.tgz";
@@ -3562,6 +3682,14 @@
       };
     }
     {
+      name = "npm_registry_fetch___npm_registry_fetch_4.0.5.tgz";
+      path = fetchurl {
+        name = "npm_registry_fetch___npm_registry_fetch_4.0.5.tgz";
+        url  = "https://registry.yarnpkg.com/npm-registry-fetch/-/npm-registry-fetch-4.0.5.tgz";
+        sha1 = "cb87cf7f25bfb048d6c3ee19d115bebf93ea5bfa";
+      };
+    }
+    {
       name = "npm_run_path___npm_run_path_2.0.2.tgz";
       path = fetchurl {
         name = "npm_run_path___npm_run_path_2.0.2.tgz";
@@ -3578,11 +3706,11 @@
       };
     }
     {
-      name = "npm___npm_6.13.7.tgz";
+      name = "npm___npm_6.14.6.tgz";
       path = fetchurl {
-        name = "npm___npm_6.13.7.tgz";
-        url  = "https://registry.yarnpkg.com/npm/-/npm-6.13.7.tgz";
-        sha1 = "9533a3ddc57f9792db8a8b303efabaf878047841";
+        name = "npm___npm_6.14.6.tgz";
+        url  = "https://registry.yarnpkg.com/npm/-/npm-6.14.6.tgz";
+        sha1 = "1a81ce1fac2bf5457dbf6342ceed503627ff228f";
       };
     }
     {
@@ -4242,11 +4370,11 @@
       };
     }
     {
-      name = "read_config_file___read_config_file_5.0.1.tgz";
+      name = "read_config_file___read_config_file_6.0.0.tgz";
       path = fetchurl {
-        name = "read_config_file___read_config_file_5.0.1.tgz";
-        url  = "https://registry.yarnpkg.com/read-config-file/-/read-config-file-5.0.1.tgz";
-        sha1 = "ead3df0d9822cc96006ca16322eaa79dac8591c2";
+        name = "read_config_file___read_config_file_6.0.0.tgz";
+        url  = "https://registry.yarnpkg.com/read-config-file/-/read-config-file-6.0.0.tgz";
+        sha1 = "224b5dca6a5bdc1fb19e63f89f342680efdb9299";
       };
     }
     {
@@ -4322,6 +4450,14 @@
       };
     }
     {
+      name = "readable_stream___readable_stream_3.6.0.tgz";
+      path = fetchurl {
+        name = "readable_stream___readable_stream_3.6.0.tgz";
+        url  = "https://registry.yarnpkg.com/readable-stream/-/readable-stream-3.6.0.tgz";
+        sha1 = "337bbda3adc0706bd3e024426a286d4b4b2c9198";
+      };
+    }
+    {
       name = "readable_stream___readable_stream_1.1.14.tgz";
       path = fetchurl {
         name = "readable_stream___readable_stream_1.1.14.tgz";
@@ -4602,6 +4738,14 @@
       };
     }
     {
+      name = "semver___semver_7.3.2.tgz";
+      path = fetchurl {
+        name = "semver___semver_7.3.2.tgz";
+        url  = "https://registry.yarnpkg.com/semver/-/semver-7.3.2.tgz";
+        sha1 = "604962b052b81ed0786aae84389ffba70ffd3938";
+      };
+    }
+    {
       name = "set_blocking___set_blocking_2.0.0.tgz";
       path = fetchurl {
         name = "set_blocking___set_blocking_2.0.0.tgz";
@@ -4698,11 +4842,11 @@
       };
     }
     {
-      name = "source_map_support___source_map_support_0.5.16.tgz";
+      name = "source_map_support___source_map_support_0.5.19.tgz";
       path = fetchurl {
-        name = "source_map_support___source_map_support_0.5.16.tgz";
-        url  = "https://registry.yarnpkg.com/source-map-support/-/source-map-support-0.5.16.tgz";
-        sha1 = "0ae069e7fe3ba7538c64c98515e35339eac5a042";
+        name = "source_map_support___source_map_support_0.5.19.tgz";
+        url  = "https://registry.yarnpkg.com/source-map-support/-/source-map-support-0.5.19.tgz";
+        sha1 = "a98b62f86dcaf4f67399648c085291ab9e8fed61";
       };
     }
     {
@@ -4994,11 +5138,11 @@
       };
     }
     {
-      name = "tar_stream___tar_stream_2.1.0.tgz";
+      name = "tar_stream___tar_stream_2.1.2.tgz";
       path = fetchurl {
-        name = "tar_stream___tar_stream_2.1.0.tgz";
-        url  = "https://registry.yarnpkg.com/tar-stream/-/tar-stream-2.1.0.tgz";
-        sha1 = "d1aaa3661f05b38b5acc9b7020efdca5179a2cc3";
+        name = "tar_stream___tar_stream_2.1.2.tgz";
+        url  = "https://registry.yarnpkg.com/tar-stream/-/tar-stream-2.1.2.tgz";
+        sha1 = "6d5ef1a7e5783a95ff70b69b97455a5968dc1325";
       };
     }
     {
@@ -5018,11 +5162,11 @@
       };
     }
     {
-      name = "temp_file___temp_file_3.3.6.tgz";
+      name = "temp_file___temp_file_3.3.7.tgz";
       path = fetchurl {
-        name = "temp_file___temp_file_3.3.6.tgz";
-        url  = "https://registry.yarnpkg.com/temp-file/-/temp-file-3.3.6.tgz";
-        sha1 = "bd7a1951338bf93b59380b498ec1804d5b76c449";
+        name = "temp_file___temp_file_3.3.7.tgz";
+        url  = "https://registry.yarnpkg.com/temp-file/-/temp-file-3.3.7.tgz";
+        sha1 = "686885d635f872748e384e871855958470aeb18a";
       };
     }
     {
@@ -5258,6 +5402,14 @@
       };
     }
     {
+      name = "universalify___universalify_1.0.0.tgz";
+      path = fetchurl {
+        name = "universalify___universalify_1.0.0.tgz";
+        url  = "https://registry.yarnpkg.com/universalify/-/universalify-1.0.0.tgz";
+        sha1 = "b61a1da173e8435b2fe3c67d29b9adf8594bd16d";
+      };
+    }
+    {
       name = "unpipe___unpipe_1.0.0.tgz";
       path = fetchurl {
         name = "unpipe___unpipe_1.0.0.tgz";
@@ -5626,11 +5778,11 @@
       };
     }
     {
-      name = "yargs_parser___yargs_parser_16.1.0.tgz";
+      name = "yargs_parser___yargs_parser_18.1.3.tgz";
       path = fetchurl {
-        name = "yargs_parser___yargs_parser_16.1.0.tgz";
-        url  = "https://registry.yarnpkg.com/yargs-parser/-/yargs-parser-16.1.0.tgz";
-        sha1 = "73747d53ae187e7b8dbe333f95714c76ea00ecf1";
+        name = "yargs_parser___yargs_parser_18.1.3.tgz";
+        url  = "https://registry.yarnpkg.com/yargs-parser/-/yargs-parser-18.1.3.tgz";
+        sha1 = "be68c4975c6b2abf469236b0c870362fab09a7b0";
       };
     }
     {
@@ -5658,11 +5810,11 @@
       };
     }
     {
-      name = "yargs___yargs_15.1.0.tgz";
+      name = "yargs___yargs_15.3.1.tgz";
       path = fetchurl {
-        name = "yargs___yargs_15.1.0.tgz";
-        url  = "https://registry.yarnpkg.com/yargs/-/yargs-15.1.0.tgz";
-        sha1 = "e111381f5830e863a89550bd4b136bb6a5f37219";
+        name = "yargs___yargs_15.3.1.tgz";
+        url  = "https://registry.yarnpkg.com/yargs/-/yargs-15.3.1.tgz";
+        sha1 = "9505b472763963e54afe60148ad27a330818e98b";
       };
     }
     {
@@ -5674,11 +5826,11 @@
       };
     }
     {
-      name = "zip_stream___zip_stream_2.1.2.tgz";
+      name = "zip_stream___zip_stream_3.0.1.tgz";
       path = fetchurl {
-        name = "zip_stream___zip_stream_2.1.2.tgz";
-        url  = "https://registry.yarnpkg.com/zip-stream/-/zip-stream-2.1.2.tgz";
-        sha1 = "841efd23214b602ff49c497cba1a85d8b5fbc39c";
+        name = "zip_stream___zip_stream_3.0.1.tgz";
+        url  = "https://registry.yarnpkg.com/zip-stream/-/zip-stream-3.0.1.tgz";
+        sha1 = "cb8db9d324a76c09f9b76b31a12a48638b0b9708";
       };
     }
   ];
diff --git a/pkgs/applications/networking/instant-messengers/element/update-element-desktop.sh b/pkgs/applications/networking/instant-messengers/element/update-element-desktop.sh
new file mode 100755
index 00000000000..ecca3018e76
--- /dev/null
+++ b/pkgs/applications/networking/instant-messengers/element/update-element-desktop.sh
@@ -0,0 +1,17 @@
+#!/usr/bin/env nix-shell
+#!nix-shell -I nixpkgs=../../../../../ -i bash -p wget yarn2nix
+
+set -euo pipefail
+
+if [ "$#" -ne 1 ] || [[ "$1" == -* ]]; then
+	echo "Regenerates the Yarn dependency lock files for the element-desktop package."
+	echo "Usage: $0 <git release tag>"
+	exit 1
+fi
+
+RIOT_WEB_SRC="https://raw.githubusercontent.com/vector-im/riot-desktop/$1"
+
+wget "$RIOT_WEB_SRC/package.json" -O element-desktop-package.json
+wget "$RIOT_WEB_SRC/yarn.lock" -O element-desktop-yarndeps.lock
+yarn2nix --lockfile=element-desktop-yarndeps.lock > element-desktop-yarndeps.nix
+rm element-desktop-yarndeps.lock
diff --git a/pkgs/applications/networking/instant-messengers/riot/update-riot-desktop.sh b/pkgs/applications/networking/instant-messengers/riot/update-riot-desktop.sh
deleted file mode 100755
index d6e7259f19b..00000000000
--- a/pkgs/applications/networking/instant-messengers/riot/update-riot-desktop.sh
+++ /dev/null
@@ -1,17 +0,0 @@
-#!/usr/bin/env nix-shell
-#!nix-shell -I nixpkgs=../../../../../ -i bash -p wget yarn2nix
-
-set -euo pipefail
-
-if [ "$#" -ne 1 ] || [[ "$1" == -* ]]; then
-	echo "Regenerates the Yarn dependency lock files for the riot-desktop package."
-	echo "Usage: $0 <git release tag>"
-	exit 1
-fi
-
-RIOT_WEB_SRC="https://raw.githubusercontent.com/vector-im/riot-desktop/$1"
-
-wget "$RIOT_WEB_SRC/package.json" -O riot-desktop-package.json
-wget "$RIOT_WEB_SRC/yarn.lock" -O riot-desktop-yarndeps.lock
-yarn2nix --lockfile=riot-desktop-yarndeps.lock > riot-desktop-yarndeps.nix
-rm riot-desktop-yarndeps.lock
diff --git a/pkgs/top-level/aliases.nix b/pkgs/top-level/aliases.nix
index ea14afa47e7..c77e06f2eba 100644
--- a/pkgs/top-level/aliases.nix
+++ b/pkgs/top-level/aliases.nix
@@ -448,6 +448,8 @@ mapAliases ({
   rdiff_backup = rdiff-backup;  # added 2014-11-23
   rdmd = dtools;  # added 2017-08-19
   rhc = throw "deprecated in 2019-04-09: abandoned by upstream.";
+  riot-desktop = element-desktop; # added 2020-07-15
+  riot-web = element-web; # added 2020-07-15
   rng_tools = rng-tools; # added 2018-10-24
   robomongo = robo3t; #added 2017-09-28
   rssglx = rss-glx; #added 2015-03-25
diff --git a/pkgs/top-level/all-packages.nix b/pkgs/top-level/all-packages.nix
index e095326a6f4..d5cef3bb426 100644
--- a/pkgs/top-level/all-packages.nix
+++ b/pkgs/top-level/all-packages.nix
@@ -1791,6 +1791,12 @@ in
 
   eksctl = callPackage ../tools/admin/eksctl { };
 
+  element-desktop = callPackage ../applications/networking/instant-messengers/element/element-desktop.nix { };
+
+  element-web = callPackage ../applications/networking/instant-messengers/element/element-web.nix {
+    conf = config.element-web.conf or {};
+  };
+
   elementary-xfce-icon-theme = callPackage ../data/icons/elementary-xfce-icon-theme { };
 
   ell = callPackage ../os-specific/linux/ell { };
@@ -2265,12 +2271,6 @@ in
 
   ring-daemon = callPackage ../applications/networking/instant-messengers/ring-daemon { };
 
-  riot-desktop = callPackage ../applications/networking/instant-messengers/riot/riot-desktop.nix { };
-
-  riot-web = callPackage ../applications/networking/instant-messengers/riot/riot-web.nix {
-    conf = config.riot-web.conf or {};
-  };
-
   ripasso-cursive = callPackage ../tools/security/ripasso/cursive.nix {
     inherit (darwin.apple_sdk.frameworks) AppKit Security;
   };
diff --git a/pkgs/applications/networking/instant-messengers/riot/riot-desktop.nix b/pkgs/applications/networking/instant-messengers/element/element-desktop.nix
index 42f8ce60fd3..6fb72ae5c9c 100644
--- a/pkgs/applications/networking/instant-messengers/riot/riot-desktop.nix
+++ b/pkgs/applications/networking/instant-messengers/element/element-desktop.nix
@@ -1,44 +1,44 @@
 { stdenv, fetchFromGitHub
 , makeWrapper, makeDesktopItem, mkYarnPackage
-, electron_7, riot-web
+, electron_9, element-web
 }:
 # Notes for maintainers:
 # * versions of `riot-web` and `riot-desktop` should be kept in sync.
 # * the Yarn dependency expression must be updated with `./update-riot-desktop.sh <git release tag>`
 
 let
-  executableName = "riot-desktop";
-  version = "1.6.7";
+  executableName = "element-desktop";
+  version = "1.7.0";
   src = fetchFromGitHub {
     owner = "vector-im";
     repo = "riot-desktop";
     rev = "v${version}";
-    sha256 = "0l1ih7rkb0nnc79607kkg0k69j9kwqrczhgkqzsmvqxjz7pk9kgn";
+    sha256 = "10qisz2s5w2ykh3j4bldadjzb4j963z5n0jd64dxmz9l2k9id2mk";
   };
-  electron = electron_7;
+  electron = electron_9;
 
 in mkYarnPackage rec {
-  name = "riot-desktop-${version}";
+  name = "element-desktop-${version}";
   inherit version src;
 
-  packageJSON = ./riot-desktop-package.json;
-  yarnNix = ./riot-desktop-yarndeps.nix;
+  packageJSON = ./element-desktop-package.json;
+  yarnNix = ./element-desktop-yarndeps.nix;
 
   nativeBuildInputs = [ makeWrapper ];
 
   installPhase = ''
     # resources
-    mkdir -p "$out/share/riot"
-    ln -s '${riot-web}' "$out/share/riot/webapp"
-    cp -r './deps/riot-desktop' "$out/share/riot/electron"
-    cp -r './deps/riot-desktop/res/img' "$out/share/riot"
-    rm "$out/share/riot/electron/node_modules"
-    cp -r './node_modules' "$out/share/riot/electron"
+    mkdir -p "$out/share/element"
+    ln -s '${element-web}' "$out/share/element/webapp"
+    cp -r './deps/element-desktop' "$out/share/element/electron"
+    cp -r './deps/element-desktop/res/img' "$out/share/element"
+    rm "$out/share/element/electron/node_modules"
+    cp -r './node_modules' "$out/share/element/electron"
 
     # icons
-    for icon in $out/share/riot/electron/build/icons/*.png; do
+    for icon in $out/share/element/electron/build/icons/*.png; do
       mkdir -p "$out/share/icons/hicolor/$(basename $icon .png)/apps"
-      ln -s "$icon" "$out/share/icons/hicolor/$(basename $icon .png)/apps/riot.png"
+      ln -s "$icon" "$out/share/icons/hicolor/$(basename $icon .png)/apps/element.png"
     done
 
     # desktop item
@@ -47,36 +47,33 @@ in mkYarnPackage rec {
 
     # executable wrapper
     makeWrapper '${electron}/bin/electron' "$out/bin/${executableName}" \
-      --add-flags "$out/share/riot/electron"
+      --add-flags "$out/share/element/electron"
   '';
 
   # Do not attempt generating a tarball for riot-web again.
   # note: `doDist = false;` does not work.
   distPhase = ''
     true
   '';
 
   # The desktop item properties should be kept in sync with data from upstream:
-  # * productName and description from
-  #   https://github.com/vector-im/riot-web/blob/develop/electron_app/package.json
-  # * category and StartupWMClass from the build.linux section of
-  #   https://github.com/vector-im/riot-web/blob/develop/package.json
+  # https://github.com/vector-im/riot-desktop/blob/develop/package.json
   desktopItem = makeDesktopItem {
-    name = "riot";
+    name = "element-desktop";
     exec = executableName;
-    icon = "riot";
-    desktopName = "Riot";
+    icon = "element";
+    desktopName = "Element (Riot)";
     genericName = "Matrix Client";
     comment = meta.description;
     categories = "Network;InstantMessaging;Chat;";
     extraEntries = ''
-      StartupWMClass=riot
+      StartupWMClass=element
     '';
   };
 
   meta = with stdenv.lib; {
     description = "A feature-rich client for Matrix.org";
-    homepage = "https://about.riot.im/";
+    homepage = "https://element.io/";
     license = licenses.asl20;
     maintainers = teams.matrix.members;
     inherit (electron.meta) platforms;
@@ -1,44 +1,44 @@
 }:
 # Notes for maintainers:
-# * versions of `riot-web` and `riot-desktop` should be kept in sync.
-# * the Yarn dependency expression must be updated with `./update-riot-desktop.sh <git release tag>`
+# * versions of `element-web` and `element-desktop` should be kept in sync.
+# * the Yarn dependency expression must be updated with `./update-element-desktop.sh <git release tag>`
 
 let
@@ -47,36 +47,33 @@ in mkYarnPackage rec {
   '';
 
-  # Do not attempt generating a tarball for riot-web again.
+  # Do not attempt generating a tarball for element-web again.
   # note: `doDist = false;` does not work.
   distPhase = ''
diff --git a/pkgs/applications/networking/instant-messengers/riot/riot-web.nix b/pkgs/applications/networking/instant-messengers/element/element-web.nix
index fc8351e73e6..533ca2a7763 100644
--- a/pkgs/applications/networking/instant-messengers/riot/riot-web.nix
+++ b/pkgs/applications/networking/instant-messengers/element/element-web.nix
@@ -1,22 +1,22 @@
 { lib, stdenv, fetchurl, writeText, jq, conf ? {} }:
 
 # Note for maintainers:
 # Versions of `riot-web` and `riot-desktop` should be kept in sync.
 
 let
   noPhoningHome = {
     disable_guests = true; # disable automatic guest account registration at matrix.org
     piwik = false; # disable analytics
   };
-  configOverrides = writeText "riot-config-overrides.json" (builtins.toJSON (noPhoningHome // conf));
+  configOverrides = writeText "element-config-overrides.json" (builtins.toJSON (noPhoningHome // conf));
 
 in stdenv.mkDerivation rec {
-  pname = "riot-web";
-  version = "1.6.8";
+  pname = "element-web";
+  version = "1.7.0";
 
   src = fetchurl {
     url = "https://github.com/vector-im/riot-web/releases/download/v${version}/riot-v${version}.tar.gz";
-    sha256 = "09jazixxaq9fcw3qld73hpknw7pcjg3b94hhgipl3zyn6dvqk3xv";
+    sha256 = "033793zx3c95z5ikq70kxajwlbg2b8785wrgjr1zyha3pjq79bm6";
   };
 
   installPhase = ''
@@ -31,7 +31,7 @@ in stdenv.mkDerivation rec {
 
   meta = {
     description = "A glossy Matrix collaboration client for the web";
-    homepage = "http://riot.im/";
+    homepage = "https://element.io/";
     maintainers = stdenv.lib.teams.matrix.members;
     license = stdenv.lib.licenses.asl20;
     platforms = stdenv.lib.platforms.all;
@@ -1,22 +1,22 @@
 
 # Note for maintainers:
-# Versions of `riot-web` and `riot-desktop` should be kept in sync.
+# Versions of `element-web` and `element-desktop` should be kept in sync.
 
 let